==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="97"/>
        <source>File Information</source>
        <translation>Filoplysninger</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Ejer:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Tilladelser:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Oprettet:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Note: Det tidspunkt en fil blev oprettet kan være nyere end tiden den blev ændret, hvis filens tilladelser er blevet ændret fornyligt.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>MimeType:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="140"/>
        <source>Edit Shortcut</source>
        <translation>Redigér genvej</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Arbejdsmappe:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Brug opstartspåmindelser</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Intet ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="61"/>
        <source>---Calculating---</source>
        <translation>---Beregner---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read/Write</source>
        <translation>Læs/Skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Read Only</source>
        <translation>Skrivebeskyttet</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>Write Only</source>
        <translation>Kun skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="73"/>
        <source>No Access</source>
        <translation>Ingen adgang</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>XDG Shortcut</source>
        <translation>XDG genvej</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Directory</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Binary</source>
        <translation>Binær fil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="81"/>
        <source>Hidden %1</source>
        <translation>Skjult %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="126"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Save Application File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Application Registrations (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="290"/>
        <source>Select a binary</source>
        <translation>Vælg en binær fil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="305"/>
        <source>Select a directory</source>
        <translation>Vælg en mappe</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Select an icon</source>
        <translation>Vælg et ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Billeder (%1);; Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source> Folders: </source>
        <translation> Mapper: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source>Files: </source>
        <translation>Filer: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="343"/>
        <source>  Calculating...</source>
        <translation>  Beregner...</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="96"/>
        <source>File Information</source>
        <translation>Filinformation</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Ejer:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Tilladelser:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Oprettet:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Note: Det tidspunkt en fil blev oprettet kan være nyere end tiden den blev ændret, hvis filens tilladelser er blevet ændret fornyligt.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Sidst ændret:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>MIME-type:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Filstørrelse:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="139"/>
        <source>Edit Shortcut</source>
        <translation>Rediger genvej</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Arbejdsmappe:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Brug opstartspåmindelser</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Kør i terminal</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Intet ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="60"/>
        <source>---Calculating---</source>
        <translation>---Beregner---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <source>Read/Write</source>
        <translation>Læs/skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read Only</source>
        <translation>Skrivebeskyttet</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Write Only</source>
        <translation>Kun skriv</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>No Access</source>
        <translation>Ingen adgang</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="76"/>
        <source>XDG Shortcut</source>
        <translation>XDG-genvej</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Directory</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Binary</source>
        <translation>Binær</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="80"/>
        <source>Hidden %1</source>
        <translation>Skjult %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="125"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Save Application File</source>
        <translation>Gem programfil</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Application Registrations (*.desktop)</source>
        <translation>Programregistreringer (*.desktop)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="288"/>
        <source>Select a binary</source>
        <translation>Vælg en binær</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Ugyldigt valg: Ikke en eksekverbar</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="303"/>
        <source>Select a directory</source>
        <translation>Vælg en mappe</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Select an icon</source>
        <translation>Vælg et ikon</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Billeder (%1);; Alle filer (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source> Folders: </source>
        <translation> Mapper: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source>Files: </source>
        <translation>Filer: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <source>  Calculating...</source>
        <translation>  Beregner ...</translation>
    </message>
</context>
</TS>
